@@ -1,12 +1,14 @@
 package File::Slurper::Temp;
 
-our $DATE = '2019-07-21'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-02'; # DATE
+our $DIST = 'File-Slurper-Temp'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
 
-use Carp 'croak';
+use Carp 'croak', 'carp';
 use File::Slurper ();
 use File::Temp ();
 
@@ -16,20 +18,32 @@ our @EXPORT_OK = qw(
                        write_text_to_tempfile write_binary_to_tempfile
                );
 
-our $FILE_TEMP_TEMPLATE = "XXXXXXXXXX";
 our $FILE_TEMP_DIR;
+our $FILE_TEMP_PERMS;
+our $FILE_TEMP_TEMPLATE = "XXXXXXXXXX";
 
 sub _tempfile {
     my $target_filename = shift;
 
     my @tfargs;
+
     push @tfargs, $FILE_TEMP_TEMPLATE;
+
     my $dir = $FILE_TEMP_DIR;
     unless (defined $dir) {
-        require File::Spec;
-        (undef, $dir, undef) = File::Spec->splitpath($target_filename);
+        require File::Basename;
+        $dir = File::Basename::dirname($target_filename);
     }
     push @tfargs, DIR => $dir;
+
+    my $perms = $FILE_TEMP_PERMS;
+    unless (defined $perms) {
+        my @st = lstat($target_filename)
+        ;#    or carp "Couldn't lstat($target_filename): $!";
+        $perms = $st[2] if @st;
+    }
+    push @tfargs, PERMS => $perms if $perms;
+
     File::Temp::tempfile(@tfargs);
 }
 
@@ -73,7 +87,7 @@ File::Slurper::Temp - File::Slurper + File::Temp
 
 =head1 VERSION
 
-This document describes version 0.006 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2019-07-21.
+This document describes version 0.007 of File::Slurper::Temp (from Perl distribution File-Slurper-Temp), released on 2021-08-02.
 
 =head1 SYNOPSIS
 
@@ -106,6 +120,14 @@ L</write_text_to_tempfile> and L</write_binary_to_tempfile>. You don't have to
 specify destination path but just content to write, and the functions will
 return the temporary filename created.
 
+=head1 VARIABLES
+
+=head2 $FILE_PERM_DIR
+
+=head2 $FILE_PERM_PERMS
+
+=head2 $FILE_PERM_TEMPLATE
+
 =head1 FUNCTIONS
 
 =head2 write_text
@@ -121,9 +143,18 @@ fails.
 
 By default, the temporary file is created in the same directory as C<$filename>,
 using C<tempfile()>'s option C<< DIR => dirname($filename) >>. If you want to
-set a specific temporary directory, set C<$FILE_TEMP_DIR> (see source code). But
+set a specific temporary directory, set L</"$FILE_TEMP_DIR">. But
 keep in mind that C<rename()> doesn't work cross-device.
 
+By default, if the target file exists, the temporary file is also created with
+the same permission as the target file. Otherwise, permission is default as per
+File::Temp's default (0600). If you want to set a specific permission, set
+L</"$FILE_TEMP_PERMS">. Permission setting is done by File::Temp::tempfile()
+using its PERMS option.
+
+By default, file ownership is not changed/set. If you run this script as root,
+you might be creating files owned by root. There's no option yet to set this.
+
 =head2 write_binary
 
 Usage:
@@ -172,7 +203,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
